==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/db/d16/debug_8h.js <==
var debug_8h =
[
    [ "DEBUG", "db/d16/debug_8h.html#a0e31f1dd7faedf1439e26026594fc76e", null ],
    [ "FILE_LINE", "db/d16/debug_8h.html#a5b0925ea5ef0baf1f338812dce0273cb", null ],
    [ "TIC", "db/d16/debug_8h.html#a046212080fd3cbbb99446176a986d1b7", null ],
    [ "TOC", "db/d16/debug_8h.html#a6b5dfa8d2563cb0a0815ab55e7c9e529", null ],
    [ "debug", "db/d16/debug_8h.html#a144c8b9a0d011373ea150b3afef62b07", null ],
    [ "DumpDebugFacilityNames", "db/d16/debug_8h.html#a439a72a4e1fa2484f5e3db07ba2348af", null ],
    [ "GetDebugString", "db/d16/debug_8h.html#a25e74a4665930f327b9e86aee0a00592", null ],
    [ "GetLogPrefix", "db/d16/debug_8h.html#a5ba63d2106f17d7f207965936afbb81c", null ],
    [ "SetDebugString", "db/d16/debug_8h.html#ab8815e51f270ac460d3c19704c8f590c", null ],
    [ "ShowInfo", "db/d16/debug_8h.html#a18cb8ca0682f09d125b9e4b8df1fddc9", null ],
    [ "ShowInfoF", "db/d16/debug_8h.html#a24e3f94c695eb640d50ccc2040e91fe9", null ],
    [ "_debug_console_level", "db/d16/debug_8h.html#aa1020d9c05cf020e83bd1c6049beb035", null ],
    [ "_debug_desync_level", "db/d16/debug_8h.html#ab0b3bc61bffe4f38aeb42fa14275b496", null ],
    [ "_debug_driver_level", "db/d16/debug_8h.html#a98d0a5219820ebb370c7f9e9dba64ac9", null ],
    [ "_debug_freetype_level", "db/d16/debug_8h.html#af5ae25100caa5cfd8b088df6838be2f8", null ],
    [ "_debug_gamelog_level", "db/d16/debug_8h.html#a3f0aee7bdd903dc63694d49026c2eef6", null ],
    [ "_debug_grf_level", "db/d16/debug_8h.html#a69ed9749e30b73bb0a9ec6673c4e9a11", null ],
    [ "_debug_map_level", "db/d16/debug_8h.html#a5fd1640bfbed73f50791b88bdc9f9e53", null ],
    [ "_debug_misc_level", "db/d16/debug_8h.html#ab75bd67047cf8512c0b3565ed0e74290", null ],
    [ "_debug_net_level", "db/d16/debug_8h.html#a66e6de2fa79459b9e3e9e4c0f916db61", null ],
    [ "_debug_npf_level", "db/d16/debug_8h.html#a63129279ea538672783bac0c5ebb6eb1", null ],
    [ "_debug_oldloader_level", "db/d16/debug_8h.html#a42d24ff0644f9129f89f70303bee6c8f", null ],
    [ "_debug_script_level", "db/d16/debug_8h.html#a4229cb9bc262beaed8e40e48ecbb3392", null ],
    [ "_debug_sl_level", "db/d16/debug_8h.html#ace01e36a9e14507053715b5a57137460", null ],
    [ "_debug_sprite_level", "db/d16/debug_8h.html#a0e572a7f8bd2ccdff5172b3ee28e099e", null ],
    [ "_debug_yapf_level", "db/d16/debug_8h.html#a24487981189bbbc6e2e22fd0f927240b", null ],
    [ "_realtime_tick", "db/d16/debug_8h.html#a7e603250cde27d5e6ee08531cd07f9fc", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/db/d16/debug_8h.js <==
var debug_8h =
[
    [ "DEBUG", "db/d16/debug_8h.html#a0e31f1dd7faedf1439e26026594fc76e", null ],
    [ "FILE_LINE", "db/d16/debug_8h.html#a5b0925ea5ef0baf1f338812dce0273cb", null ],
    [ "TIC", "db/d16/debug_8h.html#a046212080fd3cbbb99446176a986d1b7", null ],
    [ "TICC", "db/d16/debug_8h.html#ae5b485aa197c423408d3c50e0180f34b", null ],
    [ "TOC", "db/d16/debug_8h.html#a6b5dfa8d2563cb0a0815ab55e7c9e529", null ],
    [ "TOCC", "db/d16/debug_8h.html#a3909b75bc67f3936c073f41c9dee9a38", null ],
    [ "debug", "db/d16/debug_8h.html#a144c8b9a0d011373ea150b3afef62b07", null ],
    [ "DumpDebugFacilityNames", "db/d16/debug_8h.html#a439a72a4e1fa2484f5e3db07ba2348af", null ],
    [ "GetDebugString", "db/d16/debug_8h.html#a25e74a4665930f327b9e86aee0a00592", null ],
    [ "GetLogPrefix", "db/d16/debug_8h.html#a5ba63d2106f17d7f207965936afbb81c", null ],
    [ "SetDebugString", "db/d16/debug_8h.html#ab8815e51f270ac460d3c19704c8f590c", null ],
    [ "ShowInfo", "db/d16/debug_8h.html#a18cb8ca0682f09d125b9e4b8df1fddc9", null ],
    [ "ShowInfoF", "db/d16/debug_8h.html#a24e3f94c695eb640d50ccc2040e91fe9", null ],
    [ "_debug_console_level", "db/d16/debug_8h.html#aa1020d9c05cf020e83bd1c6049beb035", null ],
    [ "_debug_desync_level", "db/d16/debug_8h.html#ab0b3bc61bffe4f38aeb42fa14275b496", null ],
    [ "_debug_driver_level", "db/d16/debug_8h.html#a98d0a5219820ebb370c7f9e9dba64ac9", null ],
    [ "_debug_freetype_level", "db/d16/debug_8h.html#af5ae25100caa5cfd8b088df6838be2f8", null ],
    [ "_debug_gamelog_level", "db/d16/debug_8h.html#a3f0aee7bdd903dc63694d49026c2eef6", null ],
    [ "_debug_grf_level", "db/d16/debug_8h.html#a69ed9749e30b73bb0a9ec6673c4e9a11", null ],
    [ "_debug_map_level", "db/d16/debug_8h.html#a5fd1640bfbed73f50791b88bdc9f9e53", null ],
    [ "_debug_misc_level", "db/d16/debug_8h.html#ab75bd67047cf8512c0b3565ed0e74290", null ],
    [ "_debug_net_level", "db/d16/debug_8h.html#a66e6de2fa79459b9e3e9e4c0f916db61", null ],
    [ "_debug_npf_level", "db/d16/debug_8h.html#a63129279ea538672783bac0c5ebb6eb1", null ],
    [ "_debug_oldloader_level", "db/d16/debug_8h.html#a42d24ff0644f9129f89f70303bee6c8f", null ],
    [ "_debug_script_level", "db/d16/debug_8h.html#a4229cb9bc262beaed8e40e48ecbb3392", null ],
    [ "_debug_sl_level", "db/d16/debug_8h.html#ace01e36a9e14507053715b5a57137460", null ],
    [ "_debug_sprite_level", "db/d16/debug_8h.html#a0e572a7f8bd2ccdff5172b3ee28e099e", null ],
    [ "_debug_yapf_level", "db/d16/debug_8h.html#a24487981189bbbc6e2e22fd0f927240b", null ],
    [ "_realtime_tick", "db/d16/debug_8h.html#a7e603250cde27d5e6ee08531cd07f9fc", null ]
];
